# pretty-json-loguru

## Basic usage 

```python

from pretty_json_loguru import setup_json_loguru

setup_json_loguru()

```

Install `better_exceptions` for prettier tracebacks, will be used by default.